@@ -9,18 +9,20 @@
 #define _mysql_version_h
 
 #define PROTOCOL_VERSION            10
-#define MYSQL_SERVER_VERSION       "8.0.13-4"
+#define MYSQL_SERVER_VERSION       "8.0.15-5"
 #define MYSQL_BASE_VERSION         "mysqld-8.0"
 #define MYSQL_SERVER_SUFFIX_DEF    ""
-#define MYSQL_VERSION_ID            80013
+#define MYSQL_VERSION_ID            80015
 #define MYSQL_PORT                  3306
+#define MYSQL_ADMIN_PORT            33062
 #define MYSQL_PORT_DEFAULT          0
 #define MYSQL_UNIX_ADDR            "/run/mysqld/mysqld.sock"
 #define MYSQL_CONFIG_NAME          "my"
 #define MYSQL_PERSIST_CONFIG_NAME  "mysqld-auto"
 #define MYSQL_COMPILATION_COMMENT  "Source distribution"
-#define LIBMYSQL_VERSION           "8.0.13-4"
-#define LIBMYSQL_VERSION_ID         80013
+#define MYSQL_COMPILATION_COMMENT_SERVER  "Source distribution"
+#define LIBMYSQL_VERSION           "8.0.15-5"
+#define LIBMYSQL_VERSION_ID         80015
 #define SYS_SCHEMA_VERSION         "2.0.0"
 
 #ifndef LICENSE
